@@ -2,4 +2,7 @@ from cluster_parts.utils._types.cluster import ClusterInitType
 from cluster_parts.utils._types.features import FeatureComposition
 from cluster_parts.utils._types.features import FeatureType
 from cluster_parts.utils._types.threshold import ThresholdType
+from cluster_parts.utils.operations import box_rescaled
+from cluster_parts.utils.operations import grad2saliency
 from cluster_parts.utils.operations import l2_norm
+from cluster_parts.utils.operations import normalize
