@@ -12,9 +12,13 @@ class ClusterInitType(BaseChoiceType):
 	Default = MAXIMAS
 
 	def __call__(self, grad, K=None):
+		assert grad.ndim == 2, \
+			f"Incorrect input: {grad.ndim=} != 2!"
 
 		if self == ClusterInitType.MAXIMAS:
-			return peak_local_max(grad, num_peaks=K).T
+			peaks = peak_local_max(grad, num_peaks=K).T
+			return peaks if peaks.shape[1] == K else None
+
 
 		elif self == ClusterInitType.MIN_MAX:
 
